@@ -20,6 +20,7 @@
 
 #include <string.h>
 
+#include "gva-categories.h"
 #include "gva-error.h"
 #include "gva-favorites.h"
 #include "gva-mame.h"
@@ -171,6 +172,12 @@
                 "default_ DEFAULT 'no' " \
                 "CHECK (default_ in ('yes', 'no')));"
 
+#define SQL_CREATE_VIEW_AVAILABLE \
+        "CREATE VIEW IF NOT EXISTS available AS " \
+                "SELECT *, getcategory(name) AS category, " \
+                "isfavorite(name) AS favorite FROM game " \
+                "WHERE (romset IN ('good', 'best available'))"
+
 #define SQL_INSERT_GAME \
         "INSERT INTO game VALUES (" \
                 "@name, " \
@@ -272,9 +279,6 @@
                 "@name, " \
                 "@default_);"
 
-#define SQL_DELETE_NOT_FOUND \
-        "DELETE FROM game WHERE romset == \"not found\";"
-
 typedef struct _ParserData ParserData;
 
 struct _ParserData
@@ -1174,79 +1178,6 @@ db_parser_exit (GvaProcess *process,
         db_parser_data_free (data);
 }
 
-static void
-db_verify_read (const gchar *name,
-                const gchar *status,
-                GHashTable *hash_table)
-{
-        GString *string;
-
-        /* Build a quoted, comma-separated list of games. */
-        string = g_hash_table_lookup (hash_table, status);
-        if (string != NULL)
-                g_string_append_printf (string, ", \"%s\"", name);
-        else
-        {
-                string = g_string_sized_new (1024);
-                g_string_printf (string, "\"%s\"", name);
-                g_hash_table_insert (hash_table, g_strdup (status), string);
-        }
-}
-
-/* Helper for db_verify_exit() */
-static void
-db_verify_foreach (const gchar *status,
-                   GString *names,
-                   const gchar *column)
-{
-        gchar *sql;
-        GError *error = NULL;
-
-        sql = g_strdup_printf (
-                "UPDATE game SET %s=\"%s\" WHERE name IN (%s)",
-                column, status, names->str);
-        gva_db_execute (sql, &error);
-        gva_error_handle (&error);
-        g_free (sql);
-}
-
-static void
-db_verify_exit (GvaProcess *process,
-                gint status,
-                GHashTable *results)
-{
-        const gchar *column;
-        GError *error = NULL;
-
-        if (process->error != NULL)
-                return;
-
-        column = g_object_get_data (G_OBJECT (process), "column");
-        g_assert (column != NULL);
-
-        gva_db_transaction_begin (&error);
-        gva_error_handle (&error);
-
-        g_hash_table_foreach (
-                results, (GHFunc) db_verify_foreach, (gpointer) column);
-
-        /* This part only really applies to romsets, but I suppose there's
-         * no harm in executing it twice. */
-        gva_db_execute (SQL_DELETE_NOT_FOUND, &error);
-        gva_error_handle (&error);
-
-        gva_db_transaction_commit (&error);
-        gva_error_handle (&error);
-
-        g_hash_table_destroy (results);
-}
-
-static void
-db_verify_string_free (GString *string)
-{
-        g_string_free (string, TRUE);
-}
-
 static gboolean
 db_create_tables (GError **error)
 {
@@ -1259,7 +1190,35 @@ db_create_tables (GError **error)
                 && gva_db_execute (SQL_CREATE_TABLE_CHIP, error)
                 && gva_db_execute (SQL_CREATE_TABLE_DISPLAY, error)
                 && gva_db_execute (SQL_CREATE_TABLE_CONTROL, error)
-                && gva_db_execute (SQL_CREATE_TABLE_DIPVALUE, error);
+                && gva_db_execute (SQL_CREATE_TABLE_DIPVALUE, error)
+                && gva_db_execute (SQL_CREATE_VIEW_AVAILABLE, error);
+}
+
+static void
+db_function_getcategory (sqlite3_context *context,
+                         gint n_values,
+                         sqlite3_value **values)
+{
+#ifdef CATEGORY_FILE
+        const gchar *name;
+        gchar *category;
+        GError *error = NULL;
+
+        g_assert (n_values == 1);
+
+        name = (const gchar *) sqlite3_value_text (values[0]);
+        category = gva_categories_lookup (name, &error);
+	gva_error_handle (&error);
+
+        if (category != NULL)
+                sqlite3_result_text (context, category, -1, SQLITE_TRANSIENT);
+	else
+		sqlite3_result_null (context);
+
+	g_free (category);
+#else
+	sqlite3_result_null (context);
+#endif
 }
 
 static void
@@ -1278,6 +1237,12 @@ db_function_isfavorite (sqlite3_context *context,
                 sqlite3_result_text (context, "no", -1, SQLITE_STATIC);
 }
 
+static void
+db_trace_cb (gpointer unused, const gchar *message)
+{
+        g_debug ("%s", message);
+}
+
 /**
  * gva_db_init:
  * @error: return location for a #GError, or %NULL
@@ -1302,12 +1267,21 @@ gva_db_init (GError **error)
         if (sqlite3_open (filename, &db) != SQLITE_OK)
                 goto fail;
 
+        if (gva_get_debug_flags () & GVA_DEBUG_SQL)
+                sqlite3_trace (db, db_trace_cb, NULL);
+
         errcode = sqlite3_create_function (
                 db, "isfavorite", 1, SQLITE_ANY, NULL,
                 db_function_isfavorite, NULL, NULL);
         if (errcode != SQLITE_OK)
                 goto fail;
 
+        errcode = sqlite3_create_function (
+                db, "getcategory", 1, SQLITE_ANY, NULL,
+                db_function_getcategory, NULL, NULL);
+        if (errcode != SQLITE_OK)
+                goto fail;
+
         return db_create_tables (error);
 
 fail:
@@ -1430,88 +1404,6 @@ gva_db_build (GError **error)
         return process;
 }
 
-/**
- * gva_db_verify_romsets:
- * @error: return location for a #GError, or %NULL
- *
- * Starts the lengthy process of verifying the integrity of the available
- * ROM sets and returns a #GvaProcess to track it.  The results of the
- * verification process are written to the "romset" column of the game
- * database.  If an error occurs while starting the verification process,
- * it returns %NULL and sets @error.
- *
- * Returns: a new #GvaProcess, or %NULL
- **/
-GvaProcess *
-gva_db_verify_romsets (GError **error)
-{
-        GvaProcess *process;
-        GHashTable *results;
-
-        results = g_hash_table_new_full (
-                g_str_hash, g_str_equal,
-                (GDestroyNotify) g_free,
-                (GDestroyNotify) db_verify_string_free);
-
-        process = gva_mame_verify_roms (
-                (GvaMameCallback) db_verify_read, results, error);
-
-        if (process == NULL)
-        {
-                g_hash_table_destroy (results);
-                return NULL;
-        }
-
-        g_object_set_data (G_OBJECT (process), "column", "romset");
-
-        g_signal_connect (
-                process, "exited",
-                G_CALLBACK (db_verify_exit), results);
-
-        return process;
-}
-
-/**
- * gva_db_verify_samplesets:
- * @error: return location for a #GError, or %NULL
- *
- * Starts the lengthy process of verifying the integrity of the available
- * sample sets and returns a #GvaProcess to track it.  The results of the
- * verification process are written to the "sampleset" column of the game
- * database.  If an error occurs while starting the verification process,
- * it returns %NULL and sets @error.
- *
- * Returns: a new #GvaProcess, or %NULL
- **/
-GvaProcess *
-gva_db_verify_samplesets (GError **error)
-{
-        GvaProcess *process;
-        GHashTable *results;
-
-        results = g_hash_table_new_full (
-                g_str_hash, g_str_equal,
-                (GDestroyNotify) g_free,
-                (GDestroyNotify) db_verify_string_free);
-
-        process = gva_mame_verify_samples (
-                (GvaMameCallback) db_verify_read, results, error);
-
-        if (process == NULL)
-        {
-                g_hash_table_destroy (results);
-                return NULL;
-        }
-
-        g_object_set_data (G_OBJECT (process), "column", "sampleset");
-
-        g_signal_connect (
-                process, "exited",
-                G_CALLBACK (db_verify_exit), results);
-
-        return process;
-}
-
 /**
  * gva_db_reset:
  * @error: return location for a #GError, or %NULL
@@ -1720,7 +1612,7 @@ gva_db_get_filename (void)
 
 /**
  * gva_db_needs_rebuilt:
- * 
+ *
  * Runs a series of tests to determine whether the game database is
  * out-of-date and needs to be rebuilt.  Examples of conditions that
  * would cause a database rebuild are a new version of
