@@ -20,6 +20,7 @@
 
 #include <stdarg.h>
 
+#include "gva-audit.h"
 #include "gva-db.h"
 #include "gva-mame.h"
 #include "gva-tree-view.h"
@@ -122,7 +123,7 @@ gva_main_init (void)
         gtk_action_set_visible (GVA_ACTION_INSERT_FAVORITE, FALSE);
         gtk_action_set_visible (GVA_ACTION_REMOVE_FAVORITE, FALSE);
 
-        gtk_widget_show (GVA_WIDGET_MAIN_WINDOW);
+        gtk_window_present (GTK_WINDOW (GVA_WIDGET_MAIN_WINDOW));
 }
 
 /**
@@ -181,11 +182,11 @@ gva_main_build_database (GError **error)
         if (main_loop_quit)
                 goto exit;
 
-        process = gva_db_verify_romsets (error);
+        process = gva_audit_roms (error);
         if (process == NULL)
                 goto fail;
 
-        process2 = gva_db_verify_samplesets (error);
+        process2 = gva_audit_samples (error);
         if (process2 == NULL)
                 goto fail;
 
